import{d as u,ey as b,F as f,b as y,u as g,bu as _}from"./registerWidgets.fc9d5fd6.js";import{a as w}from"./asyncComputed.11711b1c.js";import"./gateway.f6e58b0b.js";import{M as s}from"./member.d562d1ad.js";import"./index.8156127b.js";import{C as I}from"./CrudView.953ef02c.js";import"./passwordlessManager.db68ed1a.js";import"./pubsub.44274034.js";import"./activeRecord.63df8b13.js";import"./DropdownMenu.8705b40e.js";import"./Modal.17f7550f.js";import"./LoadingIndicator.74296734.js";import"./lottie.762956c5.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="604a217e-b440-465c-98f8-7e01a0bd66ba",e._sentryDebugIdIdentifier="sentry-dbid-604a217e-b440-465c-98f8-7e01a0bd66ba")}catch{}})();const L=u({__name:"Members",setup(e){const o=b().params.organizationId,i=[{key:"email",label:"Email"}],m=async t=>{await s.create(o,t.email),c()},{loading:l,result:d,refetch:c}=w(()=>s.list(o)),p=f(()=>{var t,r;return{columns:[{name:"Email"},{name:"Role"}],rows:(r=(t=d.value)==null?void 0:t.map(n=>({key:n.email,cells:[{text:n.email,classes:["title","centered"]},{text:n.role,classes:["centered"]}]})))!=null?r:[]}});return(t,r)=>(y(),g(I,{"entity-name":"members",loading:_(l),title:"Organization members",description:"List all organization members.","empty-title":"No members yet",table:p.value,"create-button-text":"Add members",fields:i,onCreate:m},null,8,["loading","table"]))}});export{L as default};
//# sourceMappingURL=Members.93b6ca20.js.map
