import{D as f,F as t}from"./registerWidgets.fc9d5fd6.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[e]="670b6dfb-be8f-4e1f-9e87-0ec59d771fc5",r._sentryDebugIdIdentifier="sentry-dbid-670b6dfb-be8f-4e1f-9e87-0ec59d771fc5")}catch{}})();const i=r=>{const e=f({loading:!0,result:null,error:null}),n=l=>(e.value={loading:!1,result:l,error:null},l),s=l=>{e.value={loading:!1,result:null,error:l}},o=()=>{e.value={loading:!0,result:null,error:null},r().then(n).catch(s)};o();const u=t(()=>e.value.loading),a=t(()=>e.value.result),d=t(()=>e.value.error);return{loading:u,result:a,error:d,refetch:o}};export{i as a};
//# sourceMappingURL=asyncComputed.11711b1c.js.map
