import{r as c}from"./icons.c6cfa25a.js";import{d,ey as u,ex as i,a as p,b as _,c as f,e as b,bu as l,bh as m,t as y}from"./registerWidgets.fc9d5fd6.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="e21b6ce5-a8db-4926-94ff-e75f26b4b6e2",e._sentryDebugIdIdentifier="sentry-dbid-e21b6ce5-a8db-4926-94ff-e75f26b4b6e2")}catch{}})();const v=d({__name:"PreviewButton",props:{model:{}},setup(e){const t=e,o=u(),s=i(),r=()=>{const n=o.query;s.push({path:`/_editor/${t.model.routeName}/${encodeURIComponent(t.model.path)}/preview`,query:n})};return(n,w)=>{const a=p("icon");return _(),f("button",{class:"preview-button",onClick:r},[b(a,{class:"icon",path:l(c),width:"20",height:"20",fill:"#5A677A"},null,8,["path"]),m(" Preview ")])}}});const I=y(v,[["__scopeId","data-v-4b4c109d"]]);export{I as P};
//# sourceMappingURL=PreviewButton.97e8070c.js.map
