import{d as _,ey as w,ex as b,F as g,b as n,c as D,bu as u,u as p,eu as d,bw as k,t as P}from"./registerWidgets.fc9d5fd6.js";import{D as I,m as x}from"./DashPlayer.9eb66037.js";import{L as B}from"./CircularLoading.87f5a011.js";import{r as R}from"./index.8f6d8725.js";import{B as q}from"./BackButton.b5dea02d.js";import{a as l}from"./asyncComputed.11711b1c.js";import{D as C}from"./dashes.307fecbb.js";import{W as F}from"./workspaces.459fe32e.js";import"./executeJs.a6773882.js";import"./PlayerNavbar.20f5feb6.js";import"./icons.c6cfa25a.js";import"./Steps.5feb9baf.js";import"./Modal.17f7550f.js";import"./passwordlessManager.db68ed1a.js";import"./pubsub.44274034.js";import"./Passwordless.e2795335.js";import"./WidgetsFrame.6e4ea419.js";import"./lottie.762956c5.js";import"./activeRecord.63df8b13.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[r]="7da1ab06-952c-4c63-a26e-b2fb2ce33503",t._sentryDebugIdIdentifier="sentry-dbid-7da1ab06-952c-4c63-a26e-b2fb2ce33503")}catch{}})();const E=_({__name:"DashPreview",setup(t){const r=w(),s=b(),m=({id:e,type:o})=>{o==="dash"?(s.push({name:"dashPreview",params:{dashId:e},query:r.query}),y()):s.push({name:"formPreview",params:{formId:e},query:r.query})},f=()=>{var e;!((e=a.value)!=null&&e.path)||s.push(`/_editor/dash/${encodeURIComponent(a.value.path)}`)},{loading:v,result:a,refetch:y}=l(()=>C.get(r.params.dashPath)),{result:i}=l(()=>F.get()),c=g(()=>{if(!a.value||!i.value||!a.value.makeRunnerData(i.value))return null;const e=x(a.value.makeRunnerData(i.value));return e.onRedirect(({url:o,queryParams:h})=>R("preview",s,o,h)),e});return(e,o)=>(n(),D(k,null,[u(v)||!u(a)?(n(),p(B,{key:0,class:"loading",justify:"center"})):d("",!0),c.value?(n(),p(I,{key:1,class:"player",dash:c.value.runnerData,"widgets-with-errors":[],"is-preview":!0,params:u(r).query,"dash-player-service":c.value,onNavigate:m},null,8,["dash","params","dash-player-service"])):d("",!0),u(a)?(n(),p(q,{key:2,onExitFullscreenPreview:f})):d("",!0)],64))}});const Y=P(E,[["__scopeId","data-v-1172cf43"]]);export{Y as default};
//# sourceMappingURL=DashPreview.b5096ab4.js.map
