import{P as a}from"./Passwordless.e2795335.js";import{d as r,ex as d,b as i,c as _,e as s,eq as c,t as m}from"./registerWidgets.fc9d5fd6.js";import{M as p}from"./member.d562d1ad.js";import{W as f}from"./WidgetsFrame.6e4ea419.js";import"./CircularLoading.87f5a011.js";import"./lottie.762956c5.js";import"./icons.c6cfa25a.js";import"./passwordlessManager.db68ed1a.js";import"./pubsub.44274034.js";import"./gateway.f6e58b0b.js";import"./activeRecord.63df8b13.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="dd426d58-0b6a-4349-afd3-37712a8644ae",e._sentryDebugIdIdentifier="sentry-dbid-dd426d58-0b6a-4349-afd3-37712a8644ae")}catch{}})();const l={class:"login"},u=r({__name:"Login",setup(e){const o=d();async function t(n){await p.login(),o.push({name:"home"})}return(n,g)=>(i(),_("div",l,[s(f,{theme:"white","main-color":"#d14056","font-family":"sans-serif",runtime:"dash"},{default:c(()=>[s(a,{class:"passwordless",onDone:t})]),_:1})]))}});const B=m(u,[["__scopeId","data-v-0e3dc783"]]);export{B as default};
//# sourceMappingURL=Login.994d3eea.js.map
