import{M as s}from"./Modal.17f7550f.js";import{d as r,E as c,r as _,a as d,b as f,c as l,e as a,eq as i,bw as m,er as u,t as b}from"./registerWidgets.fc9d5fd6.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="34aeec4b-ba6e-43f8-87ca-8b32cf4fca32",e._sentryDebugIdIdentifier="sentry-dbid-34aeec4b-ba6e-43f8-87ca-8b32cf4fca32")}catch{}})();const p=["src"],y=r({__name:"Home",setup(e){const o=c({onboardingForm:""}),t=_(null);return(g,w)=>{const n=d("router-view");return f(),l(m,null,[a(n,{class:"router"}),a(s,{ref_key:"modal",ref:t},{content:i(()=>[u("iframe",{class:"form",src:o.onboardingForm},null,8,p)]),_:1},512)],64)}}});const x=b(y,[["__scopeId","data-v-7e290e34"]]);export{x as default};
//# sourceMappingURL=Home.29c2d0b5.js.map
