import{t as r,a,b as c,u as i,f as d,g as p,_,h as u,k as l,T as h,P as f,C as b,M as g,s as y,i as m,j as s,l as v,m as w,n as k}from"./registerWidgets.fc9d5fd6.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="5e5c11b2-5c37-4e1b-ad4e-d793c4c5cc1c",e._sentryDebugIdIdentifier="sentry-dbid-5e5c11b2-5c37-4e1b-ad4e-d793c4c5cc1c")}catch{}})();const I={};function A(e,t){const n=a("router-view");return c(),i(n,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const x=r(I,[["render",A]]),o=d({history:p("/"),routes:[{path:"/:path(.*)*",name:"player",component:()=>_(()=>import("./Player.56ba7290.js"),["assets/Player.56ba7290.js","assets/index.8f6d8725.js","assets/registerWidgets.fc9d5fd6.js","assets/registerWidgets.c3af4458.css","assets/uuid.7c316e77.js","assets/broker.b9584f05.js","assets/passwordlessManager.db68ed1a.js","assets/pubsub.44274034.js","assets/Passwordless.e2795335.js","assets/CircularLoading.87f5a011.js","assets/lottie.762956c5.js","assets/CircularLoading.f81b57b4.css","assets/icons.c6cfa25a.js","assets/Passwordless.86ac0c56.css","assets/executeJs.a6773882.js","assets/PlayerNavbar.20f5feb6.js","assets/PlayerNavbar.76a7eb2f.css","assets/Steps.5feb9baf.js","assets/Steps.998aa76d.css","assets/Modal.17f7550f.js","assets/Modal.5aaf8eba.css","assets/executeJs.887e9a58.css","assets/WidgetsFrame.6e4ea419.js","assets/WidgetsFrame.0816a5f5.css","assets/ActionButton.vue_vue_type_script_setup_true_lang.a2923034.js","assets/broker.95c7aa9a.css","assets/DashPlayer.9eb66037.js","assets/DashPlayer.4868beea.css","assets/asyncComputed.11711b1c.js","assets/Player.77337a17.css"])}],scrollBehavior(e){if(e.hash)return{el:e.hash}}});class D{static init(){setInterval(()=>fetch("/_healthcheck"),20*1e3)}}const W=()=>{const e=u({render:()=>l(x)});h.init(),D.init(),e.use(o),e.use(f),e.mount("#app"),e.component("VSelect",b),e.component("Markdown",g),e.component("Message",y),m(e,o),s(e,v),s(e,w),s(e,k)};W();
//# sourceMappingURL=player.c8103c07.js.map
